@@ -4,7 +4,12 @@ from fastapi import Query
 from progress.bar import Bar
 from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
-from pyimporters_plugins.base import KnowledgeParserOptions, KnowledgeParserBase, Term, maybe_archive
+from pyimporters_plugins.base import (
+    KnowledgeParserOptions,
+    KnowledgeParserBase,
+    Term,
+    maybe_archive,
+)
 
 
 @dataclass
@@ -12,14 +17,17 @@ class TXTOptions(KnowledgeParserOptions):
     """
     Options for the TXT knowledge import
     """
-    encoding: str = Query('utf-8', description="Encoding of the file")
+
+    encoding: str = Query("utf-8", description="Encoding of the file")
 
 
 TXTOptionsModel = TXTOptions.__pydantic_model__
 
 
 class TXTKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source: Path, options: Union[BaseModel, Dict[str, Any]], bar: Bar) -> Generator[Term, None, None]:
+    def parse(
+        self, source: Path, options: Union[BaseModel, Dict[str, Any]], bar: Bar
+    ) -> Generator[Term, None, None]:
         options = TXTOptionsModel(**options) if isinstance(options, dict) else options
         with maybe_archive(source, encoding=options.encoding) as file:
             bar.max = file_len(file)
