@@ -3,7 +3,7 @@ from pathlib import Path
 from progress.bar import Bar
 from pyimporters_plugins.base import Term
 
-from pyimporters_csv.csv import CSVKnowledgeParser, CSVOptionsModel
+from pyimporters_csv.csv_parser import CSVKnowledgeParser, CSVOptionsModel
 
 
 def check_expected(concepts):
@@ -46,3 +46,32 @@ def test_zipped_csv():
     )
     concepts = list(parser.parse(source, options.dict(), Bar("Processing")))
     check_expected(concepts)
+
+
+def test_composers():
+    testdir = Path(__file__).parent
+    source = Path(testdir, "data/composers.csv")
+    parser = CSVKnowledgeParser()
+    options = CSVOptionsModel(encoding="utf-8")
+    concepts = list(parser.parse(source, options.dict(), Bar("Processing")))
+    assert len(concepts) == 4
+    c0 = concepts[0]
+    assert c0.identifier == "Johann Sebastian Bach"
+    assert c0.preferredForm == "Johann Sebastian Bach"
+
+
+def test_lex1():
+    testdir = Path(__file__).parent
+    source = Path(testdir, "data/lex1.csv")
+    parser = CSVKnowledgeParser()
+    options = CSVOptionsModel(
+        encoding="utf-8",
+        identifier_col="identifier",
+        preferredForm_col="preferredForm",
+        altForms_cols="altForms"
+    )
+    concepts = list(parser.parse(source, options.dict(), Bar("Processing")))
+    c0 = concepts[0]
+    assert c0.identifier == "1|2"
+    assert c0.preferredForm == "toto"
+    assert c0.properties["altForms"] != "nan"
\ No newline at end of file
